pub fn transform_plan(
source: &[u8],
language: Language,
options: TransformOptions,
) -> TransformPlanExpand description
Scan source and compute its edits without building output bytes or a
source map.
This is the lazy counterpart of transform. It is useful for checkers
and report writers that only need the report or edit list.